<?php

use CKPL\Pay\Storage\StorageInterface;

require_once 'library/sdk/internals/autoload.php';

/**
 * Plugin Name: WooCommerce Conotoxia Pay Gateway
 * Plugin URI: https://conotoxia.com/payments/for-developers
 * Description: Conotoxia Pay payment gateway for WooCommerce
 * Version: 1.16.1
 * Author: Conotoxia Sp. z o.o.
 * Author URI: https://conotoxia.com
 * License: MIT
 * Text Domain: conotoxia-pay
 * Domain Path: /lang
 *
 * WC requires at least: 4.2.0
 * WC tested up to: 5.8.0
 */

add_action('plugins_loaded', 'woocommerce_conotoxia_pay_init', 0);

register_activation_hook(__FILE__, 'woocommerce_conotoxia_pay_install');
register_deactivation_hook(__FILE__, 'woocommerce_conotoxia_pay_uninstall');

const CONOTOXIA_PAY = 'conotoxia-pay';
const CONOTOXIA_PAY_VERSION = '1.16.1';

function woocommerce_conotoxia_pay_init()
{
    if (!class_exists('WC_Payment_Gateway')) {
        return;
    }

    load_plugin_textdomain(CONOTOXIA_PAY, false, dirname(plugin_basename(__FILE__)) . '/lang/');

    include_once('includes/class-woocommerce-conotoxia-pay-storage.php');
    include_once('includes/class-woocommerce-conotoxia-pay.php');

    add_filter('woocommerce_payment_gateways', 'woocommerce_conotoxia_pay_add_gateway');
}

function woocommerce_conotoxia_pay_add_gateway($methods)
{
    $methods[] = 'WC_Gateway_Conotoxia_Pay';
    return $methods;
}

function woocommerce_conotoxia_pay_install()
{
    add_option(CONOTOXIA_PAY . '-version', CONOTOXIA_PAY_VERSION);
    add_option(CONOTOXIA_PAY . '-' . StorageInterface::TOKEN, '');
    add_option(CONOTOXIA_PAY . '-' . StorageInterface::PAYMENT_SERVICE_PUBLIC_KEYS, '');
    add_option(CONOTOXIA_PAY . '-' . StorageInterface::PUBLIC_KEY_ID, '');
    add_option(CONOTOXIA_PAY . '-' . StorageInterface::PUBLIC_KEY_CHECKSUM, '');
}

function woocommerce_conotoxia_pay_uninstall()
{
    delete_option(CONOTOXIA_PAY . '-version');
    delete_option(CONOTOXIA_PAY . '-' . StorageInterface::TOKEN);
    delete_option(CONOTOXIA_PAY . '-' . StorageInterface::PAYMENT_SERVICE_PUBLIC_KEYS);
    delete_option(CONOTOXIA_PAY . '-' . StorageInterface::PUBLIC_KEY_ID);
    delete_option(CONOTOXIA_PAY . '-' . StorageInterface::PUBLIC_KEY_CHECKSUM);
}
